@@ -4,14 +4,13 @@
  *
  * PHP versions 4 and 5
  *
- * @category   pear
- * @package    PEAR
- * @author     Greg Beaver <cellog@php.net>
- * @copyright  1997-2009 The Authors
- * @license    http://opensource.org/licenses/bsd-license.php New BSD License
- * @version    CVS: $Id: rw.php 299813 2010-05-26 19:50:00Z dufuz $
- * @link       http://pear.php.net/package/PEAR
- * @since      File available since Release 1.4.0a10
+ * @category  pear
+ * @package   PEAR
+ * @author    Greg Beaver <cellog@php.net>
+ * @copyright 1997-2009 The Authors
+ * @license   http://opensource.org/licenses/bsd-license.php New BSD License
+ * @link      http://pear.php.net/package/PEAR
+ * @since     File available since Release 1.4.0a10
  */
 /**
  * Base class
@@ -24,33 +23,33 @@ require_once 'PEAR/Task/Unixeol.php';
  * @author     Greg Beaver <cellog@php.net>
  * @copyright  1997-2009 The Authors
  * @license    http://opensource.org/licenses/bsd-license.php New BSD License
- * @version    Release: 1.9.3
+ * @version    Release: 1.10.17
  * @link       http://pear.php.net/package/PEAR
  * @since      Class available since Release 1.4.0a10
  */
 class PEAR_Task_Unixeol_rw extends PEAR_Task_Unixeol
 {
-    function PEAR_Task_Unixeol_rw(&$pkg, &$config, &$logger, $fileXml)
+    function __construct(&$pkg, &$config, &$logger, $fileXml)
     {
-        parent::PEAR_Task_Common($config, $logger, PEAR_TASK_PACKAGE);
+        parent::__construct($config, $logger, PEAR_TASK_PACKAGE);
         $this->_contents = $fileXml;
         $this->_pkg = &$pkg;
         $this->_params = array();
     }
 
-    function validate()
+    public function validate()
     {
         return true;
     }
 
-    function getName()
+    public function getName()
     {
         return 'unixeol';
     }
 
-    function getXml()
+    public function getXml()
     {
         return '';
     }
 }
-?>
\ No newline at end of file
+?>
